==> dlmodeler_1.0-0.tar.gz: dlmodeler/man/dlmodeler.build.arima.Rd <==
\name{dlmodeler.build.arima}
\alias{dlmodeler.build.arima}
\title{
Build an ARIMA model
}
\description{
Builds an univariate ARIMA DLM of the specified order and coefficients.
}
\usage{
dlmodeler.build.arima(ar=c(), ma=c(), d=0,
                      sigmaH = 1, sigmaQ = 0,
                      name = "arima")
}
\arguments{
  \item{ar}{vector of autoregressive coefficients.}
  \item{ma}{vector of moving average coefficients.}
  \item{d}{order of differenciation.}
  \item{sigmaH}{std dev of the observation disturbance.}
  \item{sigmaQ}{std dev of the state disturbances.}
  \item{name}{an optional name to be given to the resulting DLM.}
}
\details{
The autoregressive terms of the model are \eqn{ar[1] + ar[2]L + ... ar[p]L^p}
where \eqn{L} is the lag operator.

The moving average terms of the model are \eqn{1 + ma[1]L + ... ma[q]L^q}
where \eqn{L} is the lag operator.

The initial value \code{P0inf} is parametered to use exact diffuse initialisation
(if supported by the back-end).

Remember: the observation disturbance is generally greater than 0, and the state
disturbance is 0 for classical deterministic models. By looking at the prototype
for this function, you can assume sigmaH refers to the observation and sigmaQ
refers to the state. This rule of thumb is useful to remember how this function
should be used.
}
\value{
An object of class \code{dlmodeler} representing the ARIMA model.
}
\references{
Durbin, and Koopman, Time Series Analysis by State Space Methods, Oxford University Press (2001),
pp. 46-48.
}
\author{
Cyrille Szymanski <cnszym@gmail.com>
}
\note{
State representations are not unique, so other forms could be used to achieve the same goals.

Currently, only ARMA models (d=0) are implemented.
}

\seealso{
\code{\link{dlmodeler}},
\code{\link{dlmodeler.build}},
\code{\link{dlmodeler.build.polynomial}},
\code{\link{dlmodeler.build.dseasonal}},
\code{\link{dlmodeler.build.tseasonal}},
\code{\link{dlmodeler.build.structural}},
\code{\link{dlmodeler.build.regression}}
}
\examples{
# Example TODO
}
\keyword{ dlm }
\keyword{ arima }

==> dlmodeler_1.2-1.tar.gz: dlmodeler/man/dlmodeler.build.arima.Rd <==
\name{dlmodeler.build.arima}
\alias{dlmodeler.build.arima}
\title{
Build an ARIMA model
}
\description{
Builds an univariate ARIMA DLM of the specified order and coefficients.
}
\usage{
dlmodeler.build.arima(ar=c(), ma=c(), d=0,
                      sigmaH = NA, sigmaQ = 0,
                      name = "arima")
}
\arguments{
  \item{ar}{vector of autoregressive coefficients.}
  \item{ma}{vector of moving average coefficients.}
  \item{d}{order of differenciation.}
  \item{sigmaH}{std dev of the observation disturbance.}
  \item{sigmaQ}{std dev of the state disturbances.}
  \item{name}{an optional name to be given to the resulting DLM.}
}
\details{
The autoregressive terms of the model are \eqn{ar[1] + ar[2]L + ... ar[p]L^p}
where \eqn{L} is the lag operator.

The moving average terms of the model are \eqn{1 + ma[1]L + ... ma[q]L^q}
where \eqn{L} is the lag operator.

The initial value \code{P0inf} is parametered to use exact diffuse initialisation
(if supported by the back-end).

Remember: all functions of this package assume by default a zero state
disturbance (deterministic states). By looking at the prototype
for this function, you can assume sigmaH refers to the observation and sigmaQ
refers to the state. This rule of thumb is useful to remember how this function
should be used.
}
\value{
An object of class \code{dlmodeler} representing the ARIMA model.
}
\references{
Durbin, and Koopman, Time Series Analysis by State Space Methods, Oxford University Press (2001),
pages 46-48.
}
\author{
Cyrille Szymanski <cnszym@gmail.com>
}
\note{
State representations are not unique, so other forms could be used to achieve the same goals.

Currently, only ARMA models (d=0) are implemented.
}

\seealso{
\code{\link{dlmodeler}}, 
\code{\link{dlmodeler.build}}, 
\code{\link{dlmodeler.build.polynomial}}, 
\code{\link{dlmodeler.build.dseasonal}}, 
\code{\link{dlmodeler.build.tseasonal}}, 
\code{\link{dlmodeler.build.structural}}, 
\code{\link{dlmodeler.build.regression}}
}
\examples{
# Example TODO
}
\keyword{ dlm }
\keyword{ arima }
